function response = hCOMMReadResponse(instrument, timeout)
%function response = hCOMMReadResponse(instrument, timeout)
%This function is invoked following a call to the hCOMMWriteCommand to 
%retrieve the response to the executed command.
%instrument - is a tcpip object
%timeout - The timeout in seconds
%response - Output structure with the following fields
    %Type - The type of the returned response
    %Message - human readable message  providing info on the status of the executed command
    %MessageLength -  byte length of the returned Message
    %Content - the content of the returned command
    %ContentLength - the length of the returned Contents

HEADER_LENGTH = 8;

SUCCESS = 0;
FAILED = 1;

errorOut = '';

header = TCPRead(instrument, HEADER_LENGTH, timeout);
status = header(1);
response.Type = header(2);
response.messageLength = typecast(header(3:4),'uint16');
response.contentLength = typecast(header(5:8),'uint32');
if(response.messageLength) > 0
    response.message = TCPRead(instrument, response.messageLength, timeout);
else
    response.message = uint8(0);
end

switch status
    case SUCCESS
        if(response.contentLength) > 0
            response.content = TCPRead(instrument, response.contentLength, timeout);
        else
            response.content = uint8(0);
        end
    case FAILED
        errorOut = ['h.API: Command Failed. ', char(response.message')];
        error(errorOut);
    otherwise
        errorOut = 'h.API: Unknown Status Value';
        error(errorOut);
end
        


