function response = hNETSetStaticNetworkSettings(instrument, address, mask, gateway)
%function response = hNETSetStaticNetworkSettings(instrument, address, mask, gateway)
%Sets the static network settings for the insrument.  If the instrument is
%currently in static mode, this will cause the current connection to become
%invalid and will need to be closed and re-opened.
%
%Parameters:
%instrument - The tcp-ip object that is connected to the Hyperion Instrument.
%address - The static IP address.  This can either be a string in
%'xxx.xxx.xxx.xxx' format, or an array of 4 integers.
%mask - The network mask.  This can either be a string in
%'xxx.xxx.xxx.xxx' format, or an array of 4 integers.
%gateway - The network gateway.  This can either be a string in
%'xxx.xxx.xxx.xxx' format, or an array of 4 integers.

%return value:
%response - A response structure returned from the instrument.
%(see hCOMMReadResponse)

if ischar(address)
    addressString = address;
else
    addressString = sprintf('%d.%d.%d.%d',address);
end

if ischar(mask)
    maskString = mask;
else
    maskString = sprintf('%d.%d.%d.%d',mask);
end

if ischar(gateway)
    gatewayString = gateway;
else
    gatewayString = sprintf('%d.%d.%d.%d',gateway);
end
argument = [addressString, ' ', maskString, ' ', gatewayString]
response = hCOMMExecuteCommand(instrument, '#SetStaticNetworkSettings',argument,0,10);


